#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_0 = {
    "Category:Children's clothing designers": "x",
    "Category:Children's clothing retailers": "x",
    "Category:Defunct department stores based in Downtown Los Angeles": "x",
    "Category:Defunct department stores based in Greater Los Angeles": "x",
    "Category:Defunct department stores based in North Hollywood": "x",
    "Category:Defunct department stores based in Southeast Los Angeles County, California": "x",
    "Category:Defunct department stores based in the Miracle Mile": "x",
    "Category:Defunct department stores based in the San Fernando Valley": "x",
    "Category:Defunct department stores based in the San Gabriel Valley": "x",
    "Category:Defunct department stores based in the South Bay, Los Angeles County": "x",
    "Category:Defunct department stores based in the Westside, Los Angeles": "x",
    "Category:Department stores in Southend-on-Sea (town)": "x",
}

data_1 = {
    "Category:Companies that have filed for bankruptcy in Canada": "تصنيف:شركات أعلنت إفلاسها في كندا",
    "Category:Clothing retailers of the United States": "تصنيف:متاجر ملابس بالتجزئة في الولايات المتحدة",
    "Category:Department stores of the United States": "تصنيف:متاجر متعددة الأقسام في الولايات المتحدة",
    "Category:Department stores of Canada": "تصنيف:متاجر متعددة الأقسام في كندا",
}

data_2 = {
    "Category:Companies that have filed for bankruptcy in Brazil": "تصنيف:شركات أعلنت إفلاسها في البرازيل",
    "Category:Companies that have filed for bankruptcy in Canada": "تصنيف:شركات أعلنت إفلاسها في كندا",
    "Category:Companies that have filed for bankruptcy in Japan": "تصنيف:شركات أعلنت إفلاسها في اليابان",
    "Category:Companies that have filed for bankruptcy in South Korea": "تصنيف:شركات أعلنت إفلاسها في كوريا الجنوبية",
    "Category:Companies that have filed for bankruptcy in the People's Republic of China": "تصنيف:شركات أعلنت إفلاسها في جمهورية الصين الشعبية",
    "Category:Companies that have filed for bankruptcy in the United States": "تصنيف:شركات أعلنت إفلاسها في الولايات المتحدة",
    "Category:Clothing retailers": "تصنيف:متاجر ملابس بالتجزئة",
    "Category:Clothing retailers by country": "تصنيف:متاجر ملابس بالتجزئة حسب البلد",
    "Category:Clothing retailers of Australia": "تصنيف:متاجر ملابس بالتجزئة في أستراليا",
    "Category:Clothing retailers of Brazil": "تصنيف:متاجر ملابس بالتجزئة في البرازيل",
    "Category:Clothing retailers of Canada": "تصنيف:متاجر ملابس بالتجزئة في كندا",
    "Category:Clothing retailers of China": "تصنيف:متاجر ملابس بالتجزئة في الصين",
    "Category:Clothing retailers of Denmark": "تصنيف:متاجر ملابس بالتجزئة في الدنمارك",
    "Category:Clothing retailers of England": "تصنيف:متاجر ملابس بالتجزئة في إنجلترا",
    "Category:Clothing retailers of France": "تصنيف:متاجر ملابس بالتجزئة في فرنسا",
    "Category:Clothing retailers of Germany": "تصنيف:متاجر ملابس بالتجزئة في ألمانيا",
    "Category:Clothing retailers of Greece": "تصنيف:متاجر ملابس بالتجزئة في اليونان",
    "Category:Clothing retailers of Greenland": "تصنيف:متاجر ملابس بالتجزئة في جرينلاند",
    "Category:Clothing retailers of Hong Kong": "تصنيف:متاجر ملابس بالتجزئة في هونغ كونغ",
    "Category:Clothing retailers of Iceland": "تصنيف:متاجر ملابس بالتجزئة في آيسلندا",
    "Category:Clothing retailers of India": "تصنيف:متاجر ملابس بالتجزئة في الهند",
    "Category:Clothing retailers of Ireland": "تصنيف:متاجر ملابس بالتجزئة في أيرلندا",
    "Category:Clothing retailers of Israel": "تصنيف:متاجر ملابس بالتجزئة في إسرائيل",
    "Category:Clothing retailers of Italy": "تصنيف:متاجر ملابس بالتجزئة في إيطاليا",
    "Category:Clothing retailers of Japan": "تصنيف:متاجر ملابس بالتجزئة في اليابان",
    "Category:Clothing retailers of Lithuania": "تصنيف:متاجر ملابس بالتجزئة في ليتوانيا",
    "Category:Clothing retailers of Mexico": "تصنيف:متاجر ملابس بالتجزئة في المكسيك",
    "Category:Clothing retailers of New Zealand": "تصنيف:متاجر ملابس بالتجزئة في نيوزيلندا",
    "Category:Clothing retailers of Nigeria": "تصنيف:متاجر ملابس بالتجزئة في نيجيريا",
    "Category:Clothing retailers of Pakistan": "تصنيف:متاجر ملابس بالتجزئة في باكستان",
    "Category:Clothing retailers of Scotland": "تصنيف:متاجر ملابس بالتجزئة في إسكتلندا",
    "Category:Clothing retailers of Spain": "تصنيف:متاجر ملابس بالتجزئة في إسبانيا",
    "Category:Clothing retailers of Sweden": "تصنيف:متاجر ملابس بالتجزئة في السويد",
    "Category:Clothing retailers of Switzerland": "تصنيف:متاجر ملابس بالتجزئة في سويسرا",
    "Category:Clothing retailers of the United Kingdom": "تصنيف:متاجر ملابس بالتجزئة في المملكة المتحدة",
    "Category:Clothing retailers of the United States": "تصنيف:متاجر ملابس بالتجزئة في الولايات المتحدة",
    "Category:Clothing retailers of Tunisia": "تصنيف:متاجر ملابس بالتجزئة في تونس",
    "Category:Clothing retailers of Wales": "تصنيف:متاجر ملابس بالتجزئة في ويلز",
    "Category:Department stores": "تصنيف:متاجر متعددة الأقسام",
    "Category:Department stores by country": "تصنيف:متاجر متعددة الأقسام حسب البلد",
    "Category:Department stores of Andorra": "تصنيف:متاجر متعددة الأقسام في أندورا",
    "Category:Department stores of Australia": "تصنيف:متاجر متعددة الأقسام في أستراليا",
    "Category:Department stores of Austria": "تصنيف:متاجر متعددة الأقسام في النمسا",
    "Category:Department stores of Brazil": "تصنيف:متاجر متعددة الأقسام في البرازيل",
    "Category:Department stores of Brunei": "تصنيف:متاجر متعددة الأقسام في بروناي",
    "Category:Department stores of Bulgaria": "تصنيف:متاجر متعددة الأقسام في بلغاريا",
    "Category:Department stores of Canada": "تصنيف:متاجر متعددة الأقسام في كندا",
    "Category:Department stores of Central America": "تصنيف:متاجر متعددة الأقسام في أمريكا الوسطى",
    "Category:Department stores of Chile": "تصنيف:متاجر متعددة الأقسام في تشيلي",
    "Category:Department stores of China": "تصنيف:متاجر متعددة الأقسام في الصين",
    "Category:Department stores of Denmark": "تصنيف:متاجر متعددة الأقسام في الدنمارك",
    "Category:Department stores of El Salvador": "تصنيف:متاجر متعددة الأقسام في السلفادور",
    "Category:Department stores of Finland": "تصنيف:متاجر متعددة الأقسام في فنلندا",
    "Category:Department stores of France": "تصنيف:متاجر متعددة الأقسام في فرنسا",
    "Category:Department stores of Germany": "تصنيف:متاجر متعددة الأقسام في ألمانيا",
    "Category:Department stores of Hong Kong": "تصنيف:متاجر متعددة الأقسام في هونغ كونغ",
    "Category:Department stores of India": "تصنيف:متاجر متعددة الأقسام في الهند",
    "Category:Department stores of Indonesia": "تصنيف:متاجر متعددة الأقسام في إندونيسيا",
    "Category:Department stores of Ireland": "تصنيف:متاجر متعددة الأقسام في أيرلندا",
    "Category:Department stores of Israel": "تصنيف:متاجر متعددة الأقسام في إسرائيل",
    "Category:Department stores of Italy": "تصنيف:متاجر متعددة الأقسام في إيطاليا",
    "Category:Department stores of Japan": "تصنيف:متاجر متعددة الأقسام في اليابان",
    "Category:Department stores of Kazakhstan": "تصنيف:متاجر متعددة الأقسام في كازاخستان",
    "Category:Department stores of Kuwait": "تصنيف:متاجر متعددة الأقسام في الكويت",
    "Category:Department stores of Lebanon": "تصنيف:متاجر متعددة الأقسام في لبنان",
    "Category:Department stores of Malaysia": "تصنيف:متاجر متعددة الأقسام في ماليزيا",
    "Category:Department stores of Mexico": "تصنيف:متاجر متعددة الأقسام في المكسيك",
    "Category:Department stores of New Zealand": "تصنيف:متاجر متعددة الأقسام في نيوزيلندا",
    "Category:Department stores of North Korea": "تصنيف:متاجر متعددة الأقسام في كوريا الشمالية",
    "Category:Department stores of Norway": "تصنيف:متاجر متعددة الأقسام في النرويج",
    "Category:Department stores of Pakistan": "تصنيف:متاجر متعددة الأقسام في باكستان",
    "Category:Department stores of Poland": "تصنيف:متاجر متعددة الأقسام في بولندا",
    "Category:Department stores of Portugal": "تصنيف:متاجر متعددة الأقسام في البرتغال",
    "Category:Department stores of Russia": "تصنيف:متاجر متعددة الأقسام في روسيا",
    "Category:Department stores of Serbia": "تصنيف:متاجر متعددة الأقسام في صربيا",
    "Category:Department stores of Singapore": "تصنيف:متاجر متعددة الأقسام في سنغافورة",
    "Category:Department stores of Slovenia": "تصنيف:متاجر متعددة الأقسام في سلوفينيا",
    "Category:Department stores of South Korea": "تصنيف:متاجر متعددة الأقسام في كوريا الجنوبية",
    "Category:Department stores of Spain": "تصنيف:متاجر متعددة الأقسام في إسبانيا",
    "Category:Department stores of Sri Lanka": "تصنيف:متاجر متعددة الأقسام في سريلانكا",
    "Category:Department stores of Sweden": "تصنيف:متاجر متعددة الأقسام في السويد",
    "Category:Department stores of Switzerland": "تصنيف:متاجر متعددة الأقسام في سويسرا",
    "Category:Department stores of Taiwan": "تصنيف:متاجر متعددة الأقسام في تايوان",
    "Category:Department stores of Thailand": "تصنيف:متاجر متعددة الأقسام في تايلاند",
    "Category:Department stores of the Netherlands": "تصنيف:متاجر متعددة الأقسام في هولندا",
    "Category:Department stores of the Philippines": "تصنيف:متاجر متعددة الأقسام في الفلبين",
    "Category:Department stores of the Soviet Union": "تصنيف:متاجر متعددة الأقسام في الاتحاد السوفيتي",
    "Category:Department stores of the United Arab Emirates": "تصنيف:متاجر متعددة الأقسام في الإمارات العربية المتحدة",
    "Category:Department stores of the United Kingdom": "تصنيف:متاجر متعددة الأقسام في المملكة المتحدة",
    "Category:Department stores of the United States": "تصنيف:متاجر متعددة الأقسام في الولايات المتحدة",
    "Category:Department stores of Turkey": "تصنيف:متاجر متعددة الأقسام في تركيا",
    "Category:Department stores of Zimbabwe": "تصنيف:متاجر متعددة الأقسام في زيمبابوي",
    "Category:Department stores on the National Register of Historic Places": "تصنيف:متاجر متعددة الأقسام في السجل الوطني للأماكن التاريخية",
    "Category:Disasters in department stores": "تصنيف:كوارث في متاجر متعددة الأقسام",
    "Category:Works set in department stores": "تصنيف:أعمال تقع أحداثها في متاجر متعددة الأقسام",
    "Category:Television shows set in department stores": "تصنيف:عروض تلفزيونية تقع أحداثها في متاجر متعددة الأقسام",
    "Category:Films set in department stores": "تصنيف:أفلام تقع أحداثها في متاجر متعددة الأقسام",
    "Category:Fiction about department stores": "تصنيف:الخيال عن متاجر متعددة الأقسام",
}

data_3 = {
    "Category:Defunct department stores based in New York State": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ولاية نيويورك",
    "Category:Defunct department stores based in Washington State": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ولاية واشنطن",
    "Category:Online clothing retailers": "تصنيف:متاجر ملابس بالتجزئة عبر الإنترنت",
    "Category:Online clothing retailers of Canada": "تصنيف:متاجر ملابس بالتجزئة عبر الإنترنت في كندا",
    "Category:Online clothing retailers of Germany": "تصنيف:متاجر ملابس بالتجزئة عبر الإنترنت في ألمانيا",
    "Category:Online clothing retailers of India": "تصنيف:متاجر ملابس بالتجزئة عبر الإنترنت في الهند",
    "Category:Online clothing retailers of Italy": "تصنيف:متاجر ملابس بالتجزئة عبر الإنترنت في إيطاليا",
    "Category:Online clothing retailers of Singapore": "تصنيف:متاجر ملابس بالتجزئة عبر الإنترنت في سنغافورة",
    "Category:Online clothing retailers of Spain": "تصنيف:متاجر ملابس بالتجزئة عبر الإنترنت في إسبانيا",
    "Category:Online clothing retailers of the United Kingdom": "تصنيف:متاجر ملابس بالتجزئة عبر الإنترنت في المملكة المتحدة",
    "Category:Online clothing retailers of the United States": "تصنيف:متاجر ملابس بالتجزئة عبر الإنترنت في الولايات المتحدة",
    "Category:Defunct clothing retailers of the United States": "تصنيف:متاجر ملابس بالتجزئة سابقة في الولايات المتحدة",
    "Category:Defunct department stores": "تصنيف:متاجر متعددة الأقسام سابقة",
    "Category:Defunct department stores based in Alabama": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ألاباما",
    "Category:Defunct department stores based in Arizona": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في أريزونا",
    "Category:Defunct department stores based in Arkansas": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في أركنساس",
    "Category:Defunct department stores based in Atlanta": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في أتلانتا (جورجيا)",
    "Category:Defunct department stores based in California": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في كاليفورنيا",
    "Category:Defunct department stores based in Chicago": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في شيكاغو",
    "Category:Defunct department stores based in Cincinnati": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في سينسيناتي",
    "Category:Defunct department stores based in Cleveland": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في كليفلاند",
    "Category:Defunct department stores based in Colorado": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في كولورادو",
    "Category:Defunct department stores based in Columbus, Ohio": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في كولومبوس (أوهايو)",
    "Category:Defunct department stores based in Connecticut": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في كونيتيكت",
    "Category:Defunct department stores based in Dayton, Ohio": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في دايتون (أوهايو)",
    "Category:Defunct department stores based in Florida": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في فلوريدا",
    "Category:Defunct department stores based in Georgia (U.S. state)": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ولاية جورجيا",
    "Category:Defunct department stores based in Hawaii": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في هاواي",
    "Category:Defunct department stores based in Hollywood": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في هوليوود",
    "Category:Defunct department stores based in Illinois": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في إلينوي",
    "Category:Defunct department stores based in Indiana": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في إنديانا",
    "Category:Defunct department stores based in Iowa": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في آيوا",
    "Category:Defunct department stores based in Kentucky": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في كنتاكي",
    "Category:Defunct department stores based in Long Beach, California": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في لونغ بيتش (كاليفورنيا)",
    "Category:Defunct department stores based in Louisiana": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في لويزيانا",
    "Category:Defunct department stores based in Maine": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في مين",
    "Category:Defunct department stores based in Maryland": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ماريلند",
    "Category:Defunct department stores based in Massachusetts": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ماساتشوستس",
    "Category:Defunct department stores based in Michigan": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ميشيغان",
    "Category:Defunct department stores based in Minnesota": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في منيسوتا",
    "Category:Defunct department stores based in Mississippi": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في مسيسيبي",
    "Category:Defunct department stores based in Missouri": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ميزوري",
    "Category:Defunct department stores based in Nebraska": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في نبراسكا",
    "Category:Defunct department stores based in Nevada": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في نيفادا",
    "Category:Defunct department stores based in New Jersey": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في نيوجيرسي",
    "Category:Defunct department stores based in New York City": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في مدينة نيويورك",
    "Category:Defunct department stores based in North Carolina": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في كارولاينا الشمالية",
    "Category:Defunct department stores based in North Dakota": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في داكوتا الشمالية",
    "Category:Defunct department stores based in Ohio": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في أوهايو",
    "Category:Defunct department stores based in Oklahoma": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في أوكلاهوما",
    "Category:Defunct department stores based in Orange County, California": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في مقاطعة أورانج (كاليفورنيا)",
    "Category:Defunct department stores based in Oregon": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في أوريغن",
    "Category:Defunct department stores based in Pennsylvania": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في بنسلفانيا",
    "Category:Defunct department stores based in Philadelphia": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في فيلادلفيا",
    "Category:Defunct department stores based in Pittsburgh": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في بيتسبرغ",
    "Category:Defunct department stores based in Sacramento": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ساكرامينتو",
    "Category:Defunct department stores based in San Bernardino County, California": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في مقاطعه سان بيرناردينو (كاليفورنيا)",
    "Category:Defunct department stores based in San Diego": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في سان دييغو",
    "Category:Defunct department stores based in South Carolina": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في كارولاينا الجنوبية",
    "Category:Defunct department stores based in Tennessee": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في تينيسي",
    "Category:Defunct department stores based in Texas": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في تكساس",
    "Category:Defunct department stores based in the City of Los Angeles": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في مدينة لوس أنجلوس",
    "Category:Defunct department stores based in the San Francisco Bay Area": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في منطقة خليج سان فرانسيسكو",
    "Category:Defunct department stores based in Toledo, Ohio": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في توليدو (أوهايو)",
    "Category:Defunct department stores based in Utah": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في يوتا",
    "Category:Defunct department stores based in Virginia": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في فرجينيا",
    "Category:Defunct department stores based in Washington, D.C.": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في واشنطن العاصمة",
    "Category:Defunct department stores based in West Virginia": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في فرجينيا الغربية",
    "Category:Defunct department stores based in Wisconsin": "تصنيف:متاجر متعددة الأقسام سابقة مقرها في ويسكونسن",
    "Category:Defunct department stores by country": "تصنيف:متاجر متعددة الأقسام سابقة حسب البلد",
    "Category:Defunct department stores of Australia": "تصنيف:متاجر متعددة الأقسام سابقة في أستراليا",
    "Category:Defunct department stores of Mexico": "تصنيف:متاجر متعددة الأقسام سابقة في المكسيك",
    "Category:Defunct department stores of Thailand": "تصنيف:متاجر متعددة الأقسام سابقة في تايلاند",
    "Category:Defunct department stores of the United Kingdom": "تصنيف:متاجر متعددة الأقسام سابقة في المملكة المتحدة",
    "Category:Defunct department stores of the United States": "تصنيف:متاجر متعددة الأقسام سابقة في الولايات المتحدة",
    "Category:Defunct department stores of the United States by city": "تصنيف:متاجر متعددة الأقسام سابقة في الولايات المتحدة حسب المدينة",
    "Category:Defunct department stores of the United States by state": "تصنيف:متاجر متعددة الأقسام سابقة في الولايات المتحدة حسب الولاية",
}


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_departments_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_departments_2(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_3.items(), ids=data_3.keys())
@pytest.mark.fast
def test_departments_3(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_departments_1", data_1),
    ("test_departments_2", data_2),
    ("test_departments_3", data_3),
]


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.dump
def test_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

geography_data = {
    "Category:Culture of Westchester County, New York": "تصنيف:ثقافة مقاطعة ويستتشستر (نيويورك)",
    "Category:Economy of Westchester County, New York": "تصنيف:اقتصاد مقاطعة ويستتشستر (نيويورك)",
    "Category:Geography of Westchester County, New York": "تصنيف:جغرافيا مقاطعة ويستتشستر (نيويورك)",
    "Category:Images of Westchester County, New York": "تصنيف:صور من مقاطعة ويستتشستر (نيويورك)",
    "Category:Landforms of Westchester County, New York": "تصنيف:تضاريس مقاطعة ويستتشستر (نيويورك)",
    "Category:Languages of the Cayman Islands": "تصنيف:لغات جزر كايمان",
    "Category:Olympic gold medalists for the United States": "تصنيف:فائزون بميداليات ذهبية أولمبية من الولايات المتحدة",
    "Category:Olympic medalists for the United States": "تصنيف:فائزون بميداليات أولمبية من الولايات المتحدة",
    "Category:Protected areas of Westchester County, New York": "تصنيف:مناطق محمية في مقاطعة ويستتشستر (نيويورك)",
}

geography_in_1 = {
    "Category:Buildings and structures in the United States by state": "تصنيف:مبان ومنشآت في الولايات المتحدة حسب الولاية",
    "Category:Buildings and structures in Westchester County, New York": "تصنيف:مبان ومنشآت في مقاطعة ويستتشستر (نيويورك)",
    "Category:Cemeteries in Westchester County, New York": "تصنيف:مقابر في مقاطعة ويستتشستر (نيويورك)",
    "Category:Centuries in the United States by state": "تصنيف:قرون في الولايات المتحدة حسب الولاية",
    "Category:Christianity in Westchester County, New York": "تصنيف:المسيحية في مقاطعة ويستتشستر (نيويورك)",
    "Category:Churches in Westchester County, New York": "تصنيف:كنائس في مقاطعة ويستتشستر (نيويورك)",
    "Category:Communications in the United States by state": "تصنيف:الاتصالات في الولايات المتحدة حسب الولاية",
    "Category:Companies based in Westchester County, New York": "تصنيف:شركات مقرها في مقاطعة ويستتشستر (نيويورك)",
    "Category:Crime in Pennsylvania": "تصنيف:جريمة في بنسلفانيا",
    "Category:Crimes in Pennsylvania": "تصنيف:جرائم في بنسلفانيا",
    "Category:Crimes in the United States by state": "تصنيف:جرائم في الولايات المتحدة حسب الولاية",
    "Category:Disasters in the United States by state": "تصنيف:كوارث في الولايات المتحدة حسب الولاية",
    "Category:Education in the United States by state": "تصنيف:التعليم في الولايات المتحدة حسب الولاية",
    "Category:Rail transport in Sri Lanka by province": "تصنيف:السكك الحديدية في سريلانكا حسب المقاطعة",
    "Category:Riots and civil disorder in the United States by state": "تصنيف:شغب وعصيان مدني في الولايات المتحدة حسب الولاية",
    "Category:Schools in Westchester County, New York": "تصنيف:مدارس في مقاطعة ويستتشستر (نيويورك)",
    "Category:Science and technology in the United States by state": "تصنيف:العلوم والتقانة في الولايات المتحدة حسب الولاية",
    "Category:Slavery in the United States by state": "تصنيف:العبودية في الولايات المتحدة حسب الولاية",
    "Category:Sports venues in Westchester County, New York": "تصنيف:ملاعب رياضية في مقاطعة ويستتشستر (نيويورك)",
    "Category:Education in Westchester County, New York": "تصنيف:التعليم في مقاطعة ويستتشستر (نيويورك)",
    "Category:Films set in China by city": "تصنيف:أفلام تقع أحداثها في الصين حسب المدينة",
    "Category:Films set in Westchester County, New York": "تصنيف:أفلام تقع أحداثها في مقاطعة ويستتشستر (نيويورك)",
    "Category:Films shot in China by city": "تصنيف:أفلام مصورة في الصين حسب المدينة",
    "Category:Forts in the United States by state": "تصنيف:حصون في الولايات المتحدة حسب الولاية",
    "Category:Health in North Dakota": "تصنيف:الصحة في داكوتا الشمالية",
    "Category:Health in the United States by state": "تصنيف:الصحة في الولايات المتحدة حسب الولاية",
}

geography_in_2 = {
    "Category:Historic districts in Westchester County, New York": "تصنيف:المناطق التاريخية في مقاطعة ويستتشستر (نيويورك)",
    "Category:Historic sites in the United States by state": "تصنيف:مواقع تاريخية في الولايات المتحدة حسب الولاية",
    "Category:Historic trails and roads in the United States by state": "تصنيف:طرق وممرات تاريخية في الولايات المتحدة حسب الولاية",
    "Category:Hospitals in Westchester County, New York": "تصنيف:مستشفيات في مقاطعة ويستتشستر (نيويورك)",
    "Category:Houses in Westchester County, New York": "تصنيف:منازل في مقاطعة ويستتشستر (نيويورك)",
    "Category:Landmarks in the United States by state": "تصنيف:معالم في الولايات المتحدة حسب الولاية",
    "Category:Manufacturing in the United States by state": "تصنيف:تصنيع في الولايات المتحدة حسب الولاية",
    "Category:Museums in Westchester County, New York": "تصنيف:متاحف في مقاطعة ويستتشستر (نيويورك)",
    "Category:National Register of Historic Places in Westchester County, New York": "تصنيف:السجل الوطني للأماكن التاريخية في مقاطعة ويستتشستر (نيويورك)",
    "Category:Nature reserves in the United States by state": "تصنيف:محميات طبيعية في الولايات المتحدة حسب الولاية",
    "Category:Olympic gold medalists for the United States in alpine skiing": "تصنيف:فائزون بميداليات ذهبية أولمبية من الولايات المتحدة في التزلج على المنحدرات الثلجية",
    "Category:Parks in Westchester County, New York": "تصنيف:متنزهات في مقاطعة ويستتشستر (نيويورك)",
    "Category:People by state in the United States": "تصنيف:أشخاص حسب الولاية في الولايات المتحدة",
    "Category:Populated places in Westchester County, New York": "تصنيف:أماكن مأهولة في مقاطعة ويستتشستر (نيويورك)",
    "Category:Television shows set in Australia by city": "تصنيف:عروض تلفزيونية تقع أحداثها في أستراليا حسب المدينة",
    "Category:Tourist attractions in the United States by state": "تصنيف:مواقع جذب سياحي في الولايات المتحدة حسب الولاية",
    "Category:Tourist attractions in Westchester County, New York": "تصنيف:مواقع جذب سياحي في مقاطعة ويستتشستر (نيويورك)",
    "Category:Transportation buildings and structures in Westchester County, New York": "تصنيف:مبان ومنشآت نقل في مقاطعة ويستتشستر (نيويورك)",
    "Category:Transportation in the United States by state": "تصنيف:النقل في الولايات المتحدة حسب الولاية",
    "Category:Transportation in Westchester County, New York": "تصنيف:النقل في مقاطعة ويستتشستر (نيويورك)",
    "Category:Universities and colleges in Westchester County, New York": "تصنيف:جامعات وكليات في مقاطعة ويستتشستر (نيويورك)",
}

test_data = [
    ("test_geography", geography_data),
    ("test_geography_in_1", geography_in_1),
    ("test_geography_in_2", geography_in_2),
]


@pytest.mark.parametrize("category, expected", geography_data.items(), ids=geography_data.keys())
@pytest.mark.fast
def test_geography(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", geography_in_1.items(), ids=geography_in_1.keys())
@pytest.mark.fast
def test_geography_in_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", geography_in_2.items(), ids=geography_in_2.keys())
@pytest.mark.fast
def test_geography_in_2(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.dump
@pytest.mark.parametrize("name,data", test_data)
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests for :mod:`make_bots.o_bots.army`.
"""

from __future__ import annotations

import pytest

from ArWikiCats.new_resolvers.countries_names_resolvers.countries_names_v2 import resolve_by_countries_names_v2

test_army_data_1 = {
    "Unmanned military aircraft of Belgium": "طائرات عسكرية بدون طيار بلجيكية",
    "Unmanned military aircraft of Canada": "طائرات عسكرية بدون طيار كندية",
    "Unmanned military aircraft of Egypt": "طائرات عسكرية بدون طيار مصرية",
    "Unmanned military aircraft of Japan": "طائرات عسكرية بدون طيار يابانية",
    "Unmanned military aircraft of Pakistan": "طائرات عسكرية بدون طيار باكستانية",
    "Unmanned military aircraft of Spain": "طائرات عسكرية بدون طيار إسبانية",
    "Unmanned military aircraft of Sweden": "طائرات عسكرية بدون طيار سويدية",
    "Unmanned aerial vehicles of Brazil": "طائرات بدون طيار برازيلية",
    "Unmanned aerial vehicles of Egypt": "طائرات بدون طيار مصرية",
    "Unmanned aerial vehicles of Iraq": "طائرات بدون طيار عراقية",
    "Unmanned aerial vehicles of Mexico": "طائرات بدون طيار مكسيكية",
    "Unmanned aerial vehicles of Morocco": "طائرات بدون طيار مغربية",
    "Unmanned aerial vehicles of Norway": "طائرات بدون طيار نرويجية",
    "Unmanned aerial vehicles of Pakistan": "طائرات بدون طيار باكستانية",
    "Unmanned aerial vehicles of Spain": "طائرات بدون طيار إسبانية",
    "Unmanned aerial vehicles of Switzerland": "طائرات بدون طيار سويسرية",
    "Unmanned aerial vehicles of Thailand": "طائرات بدون طيار تايلندية",
    "Unmanned aerial vehicles of Yemen": "طائرات بدون طيار يمنية",
}

test_army_data_2 = {
    "Unmanned military aircraft of Austria": "طائرات عسكرية بدون طيار نمساوية",
    "Unmanned military aircraft of China": "طائرات عسكرية بدون طيار صينية",
    "Unmanned military aircraft of France": "طائرات عسكرية بدون طيار فرنسية",
    "Unmanned military aircraft of Germany": "طائرات عسكرية بدون طيار ألمانية",
    "Unmanned military aircraft of Greece": "طائرات عسكرية بدون طيار يونانية",
    "Unmanned military aircraft of India": "طائرات عسكرية بدون طيار هندية",
    "Unmanned military aircraft of Iran": "طائرات عسكرية بدون طيار إيرانية",
    "Unmanned military aircraft of Israel": "طائرات عسكرية بدون طيار إسرائيلية",
    "Unmanned military aircraft of Italy": "طائرات عسكرية بدون طيار إيطالية",
    "Unmanned military aircraft of Russia": "طائرات عسكرية بدون طيار روسية",
    "Unmanned military aircraft of Turkey": "طائرات عسكرية بدون طيار تركية",
    "Unmanned military aircraft of Ukraine": "طائرات عسكرية بدون طيار أوكرانية",
    "Unmanned aerial vehicles of Algeria": "طائرات بدون طيار جزائرية",
    "Unmanned aerial vehicles of Australia": "طائرات بدون طيار أسترالية",
    "Unmanned aerial vehicles of Austria": "طائرات بدون طيار نمساوية",
    "Unmanned aerial vehicles of Belarus": "طائرات بدون طيار بيلاروسية",
    "Unmanned aerial vehicles of Canada": "طائرات بدون طيار كندية",
    "Unmanned aerial vehicles of China": "طائرات بدون طيار صينية",
    "Unmanned aerial vehicles of France": "طائرات بدون طيار فرنسية",
    "Unmanned aerial vehicles of Germany": "طائرات بدون طيار ألمانية",
    "Unmanned aerial vehicles of Greece": "طائرات بدون طيار يونانية",
    "Unmanned aerial vehicles of India": "طائرات بدون طيار هندية",
    "Unmanned aerial vehicles of Indonesia": "طائرات بدون طيار إندونيسية",
    "Unmanned aerial vehicles of Iran": "طائرات بدون طيار إيرانية",
    "Unmanned aerial vehicles of Israel": "طائرات بدون طيار إسرائيلية",
    "Unmanned aerial vehicles of Italy": "طائرات بدون طيار إيطالية",
    "Unmanned aerial vehicles of Japan": "طائرات بدون طيار يابانية",
    "Unmanned aerial vehicles of Jordan": "طائرات بدون طيار أردنية",
    "Unmanned aerial vehicles of Poland": "طائرات بدون طيار بولندية",
    "Unmanned aerial vehicles of Russia": "طائرات بدون طيار روسية",
    "Unmanned aerial vehicles of Saudi Arabia": "طائرات بدون طيار سعودية",
    "Unmanned aerial vehicles of Tunisia": "طائرات بدون طيار تونسية",
    "Unmanned aerial vehicles of Turkey": "طائرات بدون طيار تركية",
    "Unmanned aerial vehicles of Ukraine": "طائرات بدون طيار أوكرانية",
    "Unmanned aerial vehicles of the Soviet Union": "طائرات بدون طيار سوفيتية",
    "Unmanned aerial vehicles of the United Arab Emirates": "طائرات بدون طيار إماراتية",
    "Unmanned aerial vehicles of the United Kingdom": "طائرات بدون طيار بريطانية",
    "Unmanned aerial vehicles of the United States": "طائرات بدون طيار أمريكية",
}


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", test_army_data_1.items(), ids=test_army_data_1.keys())
def test_army_1(category: str, expected: str) -> None:
    result = resolve_by_countries_names_v2(category)
    assert result == expected


@pytest.mark.fast
@pytest.mark.parametrize("category,expected", test_army_data_2.items(), ids=test_army_data_2.keys())
def test_army_2(category: str, expected: str) -> None:
    result = resolve_by_countries_names_v2(category)
    assert result == expected



from typing import Dict, List, Set


def check_key_in_tables(key: str, tables: List[Dict[str, str] | List[str] | Set[str]]) -> bool:
    """Return True if ``key`` exists in any container within ``tables``."""
    for table in tables:
        if key in table or key.lower() in table:
            return True
    return False


def check_key_in_tables_return_tuple(key: str, tables: Dict[str, Dict[str, str] | Set[str]]) -> tuple[bool, str]:
    """Return presence flag and table name when ``key`` is found."""
    for name, table in tables.items():
        if key in table or key.lower() in table:
            return True, name
    return False, ""


def get_value_from_any_table(key: str, tables: List[Dict[str, str]]) -> str:
    """Return the value for ``key`` from the first mapping that contains it."""
    for table in tables:
        if key in table or key.lower() in table:
            return table[key]
    return ""



"""Unit tests"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data = {
    "Category:2020 in wheelchair basketball": "تصنيف:كرة السلة على الكراسي المتحركة في 2020",
    "Category:2020 in wheelchair rugby": "تصنيف:الرجبي على الكراسي المتحركة في 2020",
    "Category:2020 Wheelchair Basketball World Championship": "تصنيف:بطولة العالم لكرة السلة على الكراسي المتحركة 2020",
    "Category:2020 Wheelchair Basketball World Championships": "تصنيف:بطولة العالم لكرة السلة على الكراسي المتحركة 2020",
    "Category:American wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة أمريكيون",
    "Category:American wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة أمريكيون",
    "Category:American wheelchair curling champions": "تصنيف:أبطال الكيرلنغ على الكراسي المتحركة أمريكيون",
    "Category:American wheelchair discus throwers": "تصنيف:رماة قرص على الكراسي المتحركة أمريكيون",
    "Category:American wheelchair rugby players": "تصنيف:لاعبو رجبي على كراسي متحركة أمريكيون",
    "Category:American wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة أمريكيون",
    "Category:Australian wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة أستراليون",
    "Category:Australian wheelchair rugby players": "تصنيف:لاعبو رجبي على كراسي متحركة أستراليون",
    "Category:Australian wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة أستراليون",
    "Category:British wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة بريطانيون",
    "Category:British wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة بريطانيون",
    "Category:British wheelchair rugby players": "تصنيف:لاعبو رجبي على كراسي متحركة بريطانيون",
    "Category:British wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة بريطانيون",
    "Category:Cameroonian wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة كاميرونيون",
    "Category:Canadian male wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة ذكور كنديون",
    "Category:Canadian wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة كنديون",
    "Category:Canadian wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة كنديون",
    "Category:Canadian wheelchair curling champions": "تصنيف:أبطال الكيرلنغ على الكراسي المتحركة كنديون",
    "Category:Canadian wheelchair rugby players": "تصنيف:لاعبو رجبي على كراسي متحركة كنديون",
    "Category:Chinese wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة صينيون",
    "Category:Danish wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة دنماركيون",
    "Category:Dutch wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة هولنديون",
    "Category:Dutch wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة هولنديون",
    "Category:English wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة إنجليز",
    "Category:Finnish wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة فنلنديون",
    "Category:Finnish wheelchair curling champions": "تصنيف:أبطال الكيرلنغ على الكراسي المتحركة فنلنديون",
    "Category:French wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة فرنسيون",
    "Category:French wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة فرنسيون",
    "Category:German wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة ألمان",
    "Category:German wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة ألمان",
    "Category:German wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة ألمان",
    "Category:Israeli wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة إسرائيليون",
    "Category:Israeli wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة إسرائيليون",
    "Category:Italian wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة إيطاليون",
    "Category:Japanese wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة يابانيون",
    "Category:Japanese wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة يابانيون",
    "Category:Japanese wheelchair rugby players": "تصنيف:لاعبو رجبي على كراسي متحركة يابانيون",
    "Category:Japanese wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة يابانيون",
    "Category:Kuwaiti wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة كويتيون",
    "Category:Latvian wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة لاتفيون",
    "Category:National wheelchair rugby league teams": "تصنيف:منتخبات دوري رجبي على كراسي متحركة وطنية",
    "Category:Norwegian wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة نرويجيون",
}

wheelchair_racers = {
    "Category:Olympic wheelchair racers by country": "تصنيف:متسابقو كراسي متحركة أولمبيون حسب البلد",
    "Category:Olympic wheelchair racers by year": "تصنيف:متسابقو كراسي متحركة أولمبيون حسب السنة",
    "Category:Olympic wheelchair racers for Australia": "تصنيف:متسابقو كراسي متحركة أولمبيون في أستراليا",
    "Category:Olympic wheelchair racers for Canada": "تصنيف:متسابقو كراسي متحركة أولمبيون في كندا",
    "Category:Olympic wheelchair racers for France": "تصنيف:متسابقو كراسي متحركة أولمبيون في فرنسا",
    "Category:Olympic wheelchair racers for Germany": "تصنيف:متسابقو كراسي متحركة أولمبيون في ألمانيا",
    "Category:Olympic wheelchair racers for Great Britain": "تصنيف:متسابقو كراسي متحركة أولمبيون في بريطانيا العظمى",
    "Category:Olympic wheelchair racers for Japan": "تصنيف:متسابقو كراسي متحركة أولمبيون في اليابان",
    "Category:Olympic wheelchair racers for Mexico": "تصنيف:متسابقو كراسي متحركة أولمبيون في المكسيك",
    "Category:Olympic wheelchair racers for Switzerland": "تصنيف:متسابقو كراسي متحركة أولمبيون في سويسرا",
    "Category:Olympic wheelchair racers for the United States": "تصنيف:متسابقو كراسي متحركة أولمبيون في الولايات المتحدة",
    "Category:Olympic wheelchair racers": "تصنيف:متسابقو كراسي متحركة أولمبيون",
}


mens_womens = {
    "Category:Men's wheelchair basketball players by nationality": "تصنيف:لاعبو كرة سلة على كراسي متحركة حسب الجنسية",
    "Category:Men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة",
    "Category:2020 Women's World Wheelchair Basketball Championship": "تصنيف:بطولة العالم لكرة السلة على الكراسي المتحركة للسيدات 2020",
    "Category:American men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة أمريكيون",
    "Category:American women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة أمريكيات",
    "Category:Australian men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة أستراليون",
    "Category:Australian women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة أستراليات",
    "Category:British men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة بريطانيون",
    "Category:British women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة بريطانيات",
    "Category:Cameroonian men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة كاميرونيون",
    "Category:Canadian men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة كنديون",
    "Category:Canadian women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة كنديات",
    "Category:Dutch men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة هولنديون",
    "Category:Dutch women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة هولنديات",
    "Category:French men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة فرنسيون",
    "Category:French women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة فرنسيات",
    "Category:German men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة ألمان",
    "Category:German women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة ألمانيات",
    "Category:Israeli men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة إسرائيليون",
    "Category:Israeli women's wheelchair basketball players": "تصنيف:لاعبات كرة سلة على كراسي متحركة إسرائيليات",
    "Category:Japanese men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة يابانيون",
    "Category:Kuwaiti men's wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة كويتيون",
}


TEMPORAL_CASES = [
    ("test_wheelchair_1", data),
    ("test_wheelchair_racers", wheelchair_racers),
    ("test_wheelchair_mens_womens", mens_womens),
]


@pytest.mark.parametrize("category, expected", data.items(), ids=data.keys())
@pytest.mark.fast
def test_wheelchair_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", wheelchair_racers.items(), ids=wheelchair_racers.keys())
@pytest.mark.fast
def test_wheelchair_racers(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", mens_womens.items(), ids=mens_womens.keys())
@pytest.mark.fast
def test_wheelchair_mens_womens(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.dump
def test_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



from __future__ import annotations

import pytest

from ArWikiCats.new_resolvers.relations_resolver import new_relations_resolvers


@pytest.mark.unit
def test_basic_conflict_uses_p17_prefixes_with_countries_from_all_country_ar() -> None:
    """Plain 'conflict' using all_country_ar and P17_PREFIXES."""
    value = "east germany-west germany conflict"
    result = new_relations_resolvers(value)
    # ألمانيا الشرقية + ألمانيا الغربية
    # assert result == "صراع ألمانيا الشرقية وألمانيا الغربية"
    assert result == "الصراع الألماني الشرقي الألماني الغربي"


@pytest.mark.unit
def test_proxy_conflict_uses_p17_proxy_pattern() -> None:
    """'proxy conflict' formatting with two countries."""
    value = "afghanistan-africa proxy conflict"
    result = new_relations_resolvers(value)
    # أفغانستان + إفريقيا
    assert result == "صراع أفغانستان وإفريقيا بالوكالة"


@pytest.mark.unit
def test_conflict_with_en_dash_separator() -> None:
    """Conflict branch with en dash instead of hyphen."""
    value = "east germany–west germany conflict"
    result = new_relations_resolvers(value)
    # assert result == "صراع ألمانيا الشرقية وألمانيا الغربية"
    assert result == "الصراع الألماني الشرقي الألماني الغربي"


@pytest.mark.unit
def test_conflict_with_minus_sign_separator() -> None:
    """Conflict branch with minus sign instead of hyphen."""
    value = "east germany−west germany conflict"
    result = new_relations_resolvers(value)
    # assert result == "صراع ألمانيا الشرقية وألمانيا الغربية"
    assert result == "الصراع الألماني الشرقي الألماني الغربي"


@pytest.mark.unit
def test_p17_prefix_not_matched_returns_empty() -> None:
    """Non-matching suffix should not be handled by P17_PREFIXES."""
    value = "east germany-west germany relationship"
    result = new_relations_resolvers(value)
    assert result == ""


@pytest.mark.unit
def test_p17_with_unknown_country_returns_empty() -> None:
    """Unknown country key in all_country_ar should result in empty label."""
    value = "unknownland-west germany conflict"
    result = new_relations_resolvers(value)
    assert result == ""



import pytest

from ArWikiCats.translations.utils.match_sport_keys import (
    SPORTS_KEYS_FOR_JOBS,
    match_sport_key,
)

# ---------------------------------------------------------------------
# 1. Realistic category samples per sport key
# ---------------------------------------------------------------------
CATEGORY_SAMPLES = {
    # --- Wheelchair variants ---
    "Category:Wheelchair beach handball at the European Games": "wheelchair beach handball",
    "Category:automobile racing at the 2020 Paralympics": "automobile racing",
    "Category:gaelic football world championships": "gaelic football",
    "Category:kick boxing tournaments": "kick boxing",
    "Category:sport climbing events": "sport climbing",
    "Category:aquatic sports athletes": "aquatic sports",
    "Category:shooting competitions": "shooting",
    "Category:fifa world cup qualifiers": "fifa world cup",
    "Category:fifa futsal world cup finals": "fifa futsal world cup",
    "Category:shot put at the Paralympics": "shot put",
    # --- Racing variants ---
    "Category:Automobile racing in Japan": "automobile racing",
    "Category:Gaelic football racing cup": "gaelic football racing",
    "Category:Kick boxing racing finals": "kick boxing racing",
    "Category:Sport climbing racing world tour": "sport climbing racing",
    "Category:Aquatic sports racing championship": "aquatic sports racing",
    "Category:Shooting racing event winners": "shooting racing",
    "Category:Motorsports racing in the UK": "motorsports racing",
    "Category:FIFA Futsal World Cup racing series": "fifa futsal world cup racing",
    "Category:FIFA World Cup racing team awards": "fifa world cup racing",
    "Category:Beach handball racing contest": "beach handball racing",
    "Category:Shot put racing in national games": "shot put racing",
    # --- Non-racing base forms ---
    "Category:Futsal players from Spain": "futsal",
    "Category:Darts competitions in 2022": "darts",
    "Category:Basketball tournaments in Asia": "basketball",
    "Category:Esports events in Europe": "esports",
    "Category:Canoeing at the Olympics": "canoeing",
    "Category:Dressage events in France": "dressage",
    "Category:Canoe sprint at the 2019 European Games": "canoe sprint",
    "Category:Gymnastics world championships": "gymnastics",
    "Category:Korfball national teams": "korfball",
}

# ---------------------------------------------------------------------
# 2. Detection by match_sport_key
# ---------------------------------------------------------------------


@pytest.mark.fast
@pytest.mark.parametrize("category,expected_key", CATEGORY_SAMPLES.items())
def test_match_sport_key_detects_all(category: str, expected_key: str) -> None:
    """Ensure every key in SPORTS_KEYS_FOR_JOBS is detectable in sample categories."""
    result = match_sport_key(category)
    assert result.lower() == expected_key.lower(), f"Mismatch for {category}"


# ---------------------------------------------------------------------
# 3. Non-sport unrelated categories
# ---------------------------------------------------------------------
@pytest.mark.parametrize(
    "category",
    [
        "Category:Ancient history of Rome",
        "Category:Political systems by region",
        "Category:Musical instruments of Africa",
        "Category:Environmental laws in Canada",
        "Category:Writers from Yemen",
    ],
)
@pytest.mark.fast
def test_match_sport_key_returns_empty_for_irrelevant(category) -> None:
    """Return empty string for non-sport categories."""
    assert match_sport_key(category) == ""


# ---------------------------------------------------------------------
# 5. Case insensitivity
# ---------------------------------------------------------------------


@pytest.mark.parametrize(
    "category",
    [
        "category:WHEELCHAIR AUTOMOBILE RACING",
        "Category:GAELIC FOOTBALL RACING",
        "CATEGORY:SPORT CLIMBING RACING",
        "Category:ESPORTS world finals",
    ],
)
@pytest.mark.fast
def test_case_insensitivity(category) -> None:
    """Matching should ignore capitalization."""
    assert match_sport_key(category) != ""


# ---------------------------------------------------------------------
# 6. Longest match wins
# ---------------------------------------------------------------------
@pytest.mark.parametrize(
    "text,longest_key",
    [
        ("FIFA shooting racing", "shooting racing"),
        ("FIFA shooting", "shooting"),
        ("Category:FIFA Futsal World Cup racing", "fifa futsal world cup racing"),
        ("Category:FIFA Futsal World Cup", "fifa futsal world cup"),
    ],
)
@pytest.mark.fast
def test_longest_match_priority(text: str, longest_key: str) -> None:
    """When overlap exists, prefer longest key."""
    res = match_sport_key(text)
    assert res.lower() == longest_key.lower()


# ---------------------------------------------------------------------
# 7. Verify all defined keys are searchable
# ---------------------------------------------------------------------
@pytest.mark.fast
def test_all_defined_keys_detectable() -> None:
    """Ensure every key in SPORTS_KEYS_FOR_JOBS dictionary is matchable."""
    for key in SPORTS_KEYS_FOR_JOBS:
        sample = f"Category:{key.title()} Event"
        assert match_sport_key(sample), f"Key not matched: {key}"


# ---------------------------------------------------------------------
# 8. Edge cases with punctuation or spacing
# ---------------------------------------------------------------------
@pytest.mark.parametrize(
    "category",
    [
        "Category:Sport climbing, at the 2023 European Games",
        "Category:FIFA Futsal World Cup - qualifiers",
        "Category:Wheelchair Kick Boxing (Asia Championships)",
    ],
)
@pytest.mark.fast
def test_tolerates_punctuation(category) -> None:
    """Pattern should still detect keywords with punctuation nearby."""
    assert match_sport_key(category) != ""


# ---------------------------------------------------------------------
# 9. Mixed-language and noise tolerance
# ---------------------------------------------------------------------
@pytest.mark.parametrize(
    "category",
    [
        "تصنيف:FIFA futsal world cup",
        "FIFA Futsal WORLD CUP - نسخة 2016",
        "بطولة Wheelchair Sport Climbing",
    ],
)
@pytest.mark.fast
def test_mixed_language_input(category) -> None:
    """Mixed Arabic-English text should not break detection."""
    assert match_sport_key(category) != ""


# ---------------------------------------------------------------------
# 10. Sanity check: no false positives on random text
# ---------------------------------------------------------------------
@pytest.mark.parametrize(
    "category",
    [
        "Category:Poetry readings in Europe",
        "Category:Film directors by nationality",
        "Category:Hospitals in Yemen",
        "Category:Climate change effects",
    ],
)
@pytest.mark.fast
def test_no_false_positive(category) -> None:
    """Ensure non-related text never matches any sport key."""
    assert match_sport_key(category) == ""



import re


def fixing(text: str) -> str:
    """Fix text."""
    text = re.sub(r"(انحلالات|تأسيسات)\s*سنة\s*(عقد|القرن|الألفية)", r"\g<1> \g<2>", text)
    text = text.replace("بعقد عقد", "بعقد")
    text = text.replace("بعقد القرن", "بالقرن")
    return text



"""
tests
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.new_resolvers.nationalities_resolvers.nationalities_v2 import resolve_by_nats

all_test_data_integrated = {
    "Non-American television series based on American television series": "مسلسلات تلفزيونية غير أمريكية مبنية على مسلسلات تلفزيونية أمريكية",
    "American television series based on non-American television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية غير أمريكية",
    "Australian television series based on non-Australian television series": "مسلسلات تلفزيونية أسترالية مبنية على مسلسلات تلفزيونية غير أسترالية",
    "Austrian television series based on non-Austrian television series": "مسلسلات تلفزيونية نمساوية مبنية على مسلسلات تلفزيونية غير نمساوية",
    "Belgian television series based on non-Belgian television series": "مسلسلات تلفزيونية بلجيكية مبنية على مسلسلات تلفزيونية غير بلجيكية",
    "Brazilian television series based on non-Brazilian television series": "مسلسلات تلفزيونية برازيلية مبنية على مسلسلات تلفزيونية غير برازيلية",
    "British television series based on non-British television series": "مسلسلات تلفزيونية بريطانية مبنية على مسلسلات تلفزيونية غير بريطانية",
    "Bulgarian television series based on non-Bulgarian television series": "مسلسلات تلفزيونية بلغارية مبنية على مسلسلات تلفزيونية غير بلغارية",
    "Canadian television series based on non-Canadian television series": "مسلسلات تلفزيونية كندية مبنية على مسلسلات تلفزيونية غير كندية",
    "Chinese television series based on non-Chinese television series": "مسلسلات تلفزيونية صينية مبنية على مسلسلات تلفزيونية غير صينية",
    "Croatian television series based on non-Croatian television series": "مسلسلات تلفزيونية كرواتية مبنية على مسلسلات تلفزيونية غير كرواتية",
    "Czech television series based on non-Czech television series": "مسلسلات تلفزيونية تشيكية مبنية على مسلسلات تلفزيونية غير تشيكية",
    "Dutch television series based on non-Dutch television series": "مسلسلات تلفزيونية هولندية مبنية على مسلسلات تلفزيونية غير هولندية",
    "Estonian television series based on non-Estonian television series": "مسلسلات تلفزيونية إستونية مبنية على مسلسلات تلفزيونية غير إستونية",
    "Finnish television series based on non-Finnish television series": "مسلسلات تلفزيونية فنلندية مبنية على مسلسلات تلفزيونية غير فنلندية",
    "French television series based on non-French television series": "مسلسلات تلفزيونية فرنسية مبنية على مسلسلات تلفزيونية غير فرنسية",
    "Georgia (country) television series based on non-Georgia (country) television series": "مسلسلات تلفزيونية جورجية مبنية على مسلسلات تلفزيونية غير جورجية",
    "German television series based on non-German television series": "مسلسلات تلفزيونية ألمانية مبنية على مسلسلات تلفزيونية غير ألمانية",
    "Hungarian television series based on non-Hungarian television series": "مسلسلات تلفزيونية مجرية مبنية على مسلسلات تلفزيونية غير مجرية",
    "Indian television series based on non-Indian television series": "مسلسلات تلفزيونية هندية مبنية على مسلسلات تلفزيونية غير هندية",
    "Indonesian television series based on non-Indonesian television series": "مسلسلات تلفزيونية إندونيسية مبنية على مسلسلات تلفزيونية غير إندونيسية",
    "Irish television series based on non-Irish television series": "مسلسلات تلفزيونية أيرلندية مبنية على مسلسلات تلفزيونية غير أيرلندية",
    "Israeli television series based on non-Israeli television series": "مسلسلات تلفزيونية إسرائيلية مبنية على مسلسلات تلفزيونية غير إسرائيلية",
    "Italian television series based on non-Italian television series": "مسلسلات تلفزيونية إيطالية مبنية على مسلسلات تلفزيونية غير إيطالية",
    "Japanese television series based on non-Japanese television series": "مسلسلات تلفزيونية يابانية مبنية على مسلسلات تلفزيونية غير يابانية",
    "Lithuanian television series based on non-Lithuanian television series": "مسلسلات تلفزيونية ليتوانية مبنية على مسلسلات تلفزيونية غير ليتوانية",
    "Malaysian television series based on non-Malaysian television series": "مسلسلات تلفزيونية ماليزية مبنية على مسلسلات تلفزيونية غير ماليزية",
    "Mexican television series based on non-Mexican television series": "مسلسلات تلفزيونية مكسيكية مبنية على مسلسلات تلفزيونية غير مكسيكية",
    "Non-Argentine television series based on Argentine television series": "مسلسلات تلفزيونية غير أرجنتينية مبنية على مسلسلات تلفزيونية أرجنتينية",
    "Non-Australian television series based on Australian television series": "مسلسلات تلفزيونية غير أسترالية مبنية على مسلسلات تلفزيونية أسترالية",
    "Non-British television series based on British television series": "مسلسلات تلفزيونية غير بريطانية مبنية على مسلسلات تلفزيونية بريطانية",
    "Non-Canadian television series based on Canadian television series": "مسلسلات تلفزيونية غير كندية مبنية على مسلسلات تلفزيونية كندية",
    "Non-Colombian television series based on Colombian television series": "مسلسلات تلفزيونية غير كولومبية مبنية على مسلسلات تلفزيونية كولومبية",
    "Non-French television series based on French television series": "مسلسلات تلفزيونية غير فرنسية مبنية على مسلسلات تلفزيونية فرنسية",
    "Non-Japanese television series based on Japanese television series": "مسلسلات تلفزيونية غير يابانية مبنية على مسلسلات تلفزيونية يابانية",
    "Non-Pakistani television series based on Pakistani television series": "مسلسلات تلفزيونية غير باكستانية مبنية على مسلسلات تلفزيونية باكستانية",
    "Non-South Korean television series based on South Korean television series": "مسلسلات تلفزيونية غير كورية جنوبية مبنية على مسلسلات تلفزيونية كورية جنوبية",
    "Non-Spanish television series based on Spanish television series": "مسلسلات تلفزيونية غير إسبانية مبنية على مسلسلات تلفزيونية إسبانية",
    "Non-Taiwanese television series based on Taiwanese television series": "مسلسلات تلفزيونية غير تايوانية مبنية على مسلسلات تلفزيونية تايوانية",
    "Non-Turkish television series based on Turkish television series": "مسلسلات تلفزيونية غير تركية مبنية على مسلسلات تلفزيونية تركية",
    "Pakistani television series based on non-Pakistani television series": "مسلسلات تلفزيونية باكستانية مبنية على مسلسلات تلفزيونية غير باكستانية",
    "Philippine television series based on non-Philippine television series": "مسلسلات تلفزيونية فلبينية مبنية على مسلسلات تلفزيونية غير فلبينية",
    "Portuguese television series based on non-Portuguese television series": "مسلسلات تلفزيونية برتغالية مبنية على مسلسلات تلفزيونية غير برتغالية",
    "Romanian television series based on non-Romanian television series": "مسلسلات تلفزيونية رومانية مبنية على مسلسلات تلفزيونية غير رومانية",
    "Russian television series based on non-Russian television series": "مسلسلات تلفزيونية روسية مبنية على مسلسلات تلفزيونية غير روسية",
    "Singaporean television series based on non-Singaporean television series": "مسلسلات تلفزيونية سنغافورية مبنية على مسلسلات تلفزيونية غير سنغافورية",
    "South Korean television series based on non-South Korean television series": "مسلسلات تلفزيونية كورية جنوبية مبنية على مسلسلات تلفزيونية غير كورية جنوبية",
    "Spanish television series based on non-Spanish television series": "مسلسلات تلفزيونية إسبانية مبنية على مسلسلات تلفزيونية غير إسبانية",
    "Taiwanese television series based on non-Taiwanese television series": "مسلسلات تلفزيونية تايوانية مبنية على مسلسلات تلفزيونية غير تايوانية",
    "Turkish television series based on non-Turkish television series": "مسلسلات تلفزيونية تركية مبنية على مسلسلات تلفزيونية غير تركية",
    "Uruguayan television series based on non-Uruguayan television series": "مسلسلات تلفزيونية أوروغويانية مبنية على مسلسلات تلفزيونية غير أوروغويانية",
    "Vietnamese television series based on non-Vietnamese television series": "مسلسلات تلفزيونية فيتنامية مبنية على مسلسلات تلفزيونية غير فيتنامية",
}


data_series_empty = {
    "New Zealand television series based on non-New Zealand television series": "x",
    "Non-New Zealand television series based on New Zealand television series": "x",
    "Non-Tamil-language television series based on Tamil-language television series": "x",
    "Tamil-language television series based on non-Tamil-language television series": "x",
}


@pytest.mark.parametrize(
    "category, expected_key", all_test_data_integrated.items(), ids=all_test_data_integrated.keys()
)
@pytest.mark.slow
def test_with_resolve_label_ar(category: str, expected_key: str) -> None:
    label2 = resolve_label_ar(category)
    assert label2 == expected_key


to_test = [
    ("test_with_resolve_label_ar", all_test_data_integrated, resolve_label_ar),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_non_dump(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""
Resolve country names categories translations

countries_names.py use only countries names without nationalities
countries_names_v2.py use countries names with nationalities

"""
import functools
from typing import Dict

from ...helps import logger
from ...translations import countries_from_nat
from ...translations_formats import FormatData, MultiDataFormatterBase
from .countries_names_data import formatted_data_en_ar_only

# NOTE: ONLY_COUNTRY_NAMES should not merge to formatted_data_en_ar_only directly

ONLY_COUNTRY_NAMES = {
    "{en} political leader": "قادة {ar} السياسيون",
    "government ministers of {en}": "وزراء {ar}",
    "secretaries of {en}": "وزراء {ar}",
    "state lieutenant governors of {en}": "نواب حكام الولايات في {ar}",
    "state secretaries of state of {en}": "وزراء خارجية الولايات في {ar}",
}
formatted_data_updated = dict(formatted_data_en_ar_only)
formatted_data_updated.update(ONLY_COUNTRY_NAMES)
countries_from_nat_data: Dict[str, str] = dict(countries_from_nat)

# TODO: COUNTRY_LABEL_OVERRIDES already used in geo_names_formats.py


@functools.lru_cache(maxsize=1)
def _load_bot() -> MultiDataFormatterBase:
    return FormatData(
        formatted_data_updated,
        countries_from_nat_data,
        key_placeholder="{en}",
        value_placeholder="{ar}",
        text_before="the ",
        regex_filter=r"[\w-]",
    )


@functools.lru_cache(maxsize=10000)
def resolve_by_countries_names(category: str) -> str:
    logger.debug(f"<<yellow>> start resolve_by_countries_names: {category=}")

    nat_bot = _load_bot()
    result = nat_bot.search_all_category(category)

    logger.info_if_or_debug(f"<<yellow>> end resolve_by_countries_names: {category=}, {result=}", result)
    return result


__all__ = [
    "resolve_by_countries_names",
]



#!/usr/bin/python3
"""
TODO: use it instead of langs_w.py after adding
    jobs_mens_data,
    Films_key_For_nat,
    Lang_work,

"""
import functools
import re

from ..helps import logger
from ..translations import (  # Films_key_333,; Films_key_For_nat,; Films_keys_both_new_female,
    COMPLEX_LANGUAGE_TRANSLATIONS,
    PRIMARY_LANGUAGE_TRANSLATIONS,
    Films_key_CAO,
    film_keys_for_female,
)
from ..translations_formats import FormatDataV2, MultiDataFormatterBase, format_films_country_data

new_data = PRIMARY_LANGUAGE_TRANSLATIONS | COMPLEX_LANGUAGE_TRANSLATIONS

formatted_data = {
    "{en}-language comedy films": "أفلام كوميدية باللغة {al_ar}",
    "{en} language activists": "ناشطون بلغة {ar}",
    "{en}-language singers": "مغنون باللغة {al_ar}",
    "romanization of {en}": "رومنة اللغة {al_ar}",
    "{en} language countries": "بلدان اللغة {al_ar}",
    "{en} language culture": "ثقافة اللغة {al_ar}",
    "{en} language dialects": "لهجات اللغة {al_ar}",
    "{en} language categories": "تصنيفات اللغة {al_ar}",
    "{en} language education": "تعليم اللغة {al_ar}",
    "{en} language given names": "أسماء شخصية باللغة {al_ar}",
    "{en} language grammar": "قواعد اللغة {al_ar}",
    "{en} language literature": "أدب اللغة {al_ar}",
    "{en} language masculine given names": "أسماء ذكور باللغة {al_ar}",
    "{en} language mass media": "إعلام اللغة {al_ar}",
    "{en} language romanization": "رومنة اللغة {al_ar}",
    "{en} language surnames": "ألقاب باللغة {al_ar}",
    "{en} language underground culture": "ثقافة باطنية اللغة {al_ar}",
    "{en} language varieties and styles": "أصناف وأساليب اللغة {al_ar}",
    "{en} language writing system": "نظام كتابة اللغة {al_ar}",
    "{en} newspapers": "صحف باللغة {al_ar}",
    "{en} language newspapers": "صحف باللغة {al_ar}",
    "{en} phonology": "نطقيات {ar}",
    "{en} mythology": "أساطير {ar}",
    "{en} texts": "نصوص {ar}",
    "{en} prose texts": "نصوص نثرية {ar}",
    "{en} language": "لغة {ar}",
    "{en}-language": "اللغة {al_ar}",
    "{en} languages": "اللغات {al_ar}",
    "{en} languages writing system": "نظام كتابة اللغات {al_ar}",
    "{en} languages dialects": "لهجات اللغات {al_ar}",
    "{en} languages films": "أفلام باللغات {al_ar}",
    "{en} languages given names": "أسماء شخصية باللغات {al_ar}",
    "{en} languages grammar": "قواعد اللغات {al_ar}",
    "{en} languages surnames": "ألقاب باللغات {al_ar}",
    "{en} language academic journals": "دوريات أكاديمية باللغة {al_ar}",
    "{en} language albums": "ألبومات باللغة {al_ar}",
    "{en} language animation albums": "ألبومات رسوم متحركة باللغة {al_ar}",
    "{en} language books": "كتب باللغة {al_ar}",
    "{en} language comedy albums": "ألبومات كوميدية باللغة {al_ar}",
    "{en} language comic book": "كتب قصص مصورة باللغة {al_ar}",
    "{en} language comic strips": "شرائط كومكس باللغة {al_ar}",
    "{en} language comic": "قصص مصورة باللغة {al_ar}",
    "{en} language comics": "قصص مصورة باللغة {al_ar}",
    "{en} language compilation albums": "ألبومات تجميعية باللغة {al_ar}",
    "{en} language concept albums": "ألبومات مفاهيمية باللغة {al_ar}",
    "{en} language dictionaries": "قواميس باللغة {al_ar}",
    "{en} language encyclopedias": "موسوعات باللغة {al_ar}",
    "{en} language eps albums": "ألبومات أسطوانة مطولة باللغة {al_ar}",
    "{en} language film series": "سلاسل أفلام باللغة {al_ar}",
    "{en} films": "أفلام باللغة {al_ar}",
    "{en} language films": "أفلام باللغة {al_ar}",
    "{en} language folk albums": "ألبومات فولك باللغة {al_ar}",
    "{en} language folktronica albums": "ألبومات فولكترونيكا باللغة {al_ar}",
    "{en} language graphic novels": "روايات مصورة باللغة {al_ar}",
    "{en} language inscriptions": "نقوش باللغة {al_ar}",
    "{en} language jazz albums": "ألبومات جاز باللغة {al_ar}",
    "{en} language literary awards": "جوائز أدبية باللغة {al_ar}",
    "{en} language live albums": "ألبومات مباشرة باللغة {al_ar}",
    "{en} language magazines": "مجلات باللغة {al_ar}",
    "{en} language manga": "مانغا باللغة {al_ar}",
    "{en} language marvel comics": "مارفال كومكس باللغة {al_ar}",
    "{en} language media": "إعلام باللغة {al_ar}",
    "{en} language medieval literature": "أدب العصور الوسطى باللغة {al_ar}",
    "{en} language mixtape albums": "ألبومات ميكستايب باللغة {al_ar}",
    "{en} language music": "موسيقى باللغة {al_ar}",
    "{en} language musicians": "موسيقيون باللغة {al_ar}",
    "{en} language names": "أسماء باللغة {al_ar}",
    "{en} language novellas": "روايات قصيرة باللغة {al_ar}",
    "{en} language novels": "روايات باللغة {al_ar}",
    "{en} language operas": "أوبيرات باللغة {al_ar}",
    "{en} language people": "أشخاص باللغة {al_ar}",
    "{en} language plays": "مسرحيات باللغة {al_ar}",
    "{en} language poems": "قصائد باللغة {al_ar}",
    "{en} language publications": "منشورات باللغة {al_ar}",
    "{en} language radio stations": "محطات إذاعية باللغة {al_ar}",
    "{en} language remix albums": "ألبومات ريمكس باللغة {al_ar}",
    "{en} language short stories": "قصص قصيرة باللغة {al_ar}",
    "{en} language songs": "أغان باللغة {al_ar}",
    "{en} language surprise albums": "ألبومات مفاجئة باللغة {al_ar}",
    "{en} language telenovelas": "تيلينوفيلا باللغة {al_ar}",
    "{en} language television episodes": "حلقات تلفزيونية باللغة {al_ar}",
    "{en} language television networks": "شبكات تلفزيونية باللغة {al_ar}",
    "{en} language television programmes": "برامج تلفزيونية باللغة {al_ar}",
    "{en} language television programs": "برامج تلفزيونية باللغة {al_ar}",
    "{en} language television seasons": "مواسم تلفزيونية باللغة {al_ar}",
    "{en} language television series": "مسلسلات تلفزيونية باللغة {al_ar}",
    "{en} language television shows": "عروض تلفزيونية باللغة {al_ar}",
    "{en} language television stations": "محطات تلفزيونية باللغة {al_ar}",
    "{en} language television": "تلفاز باللغة {al_ar}",
    "{en} language verbs": "أفعال باللغة {al_ar}",
    "{en} language video albums": "ألبومات فيديو باللغة {al_ar}",
    "{en} language video games": "ألعاب فيديو باللغة {al_ar}",
    "{en} language webcomic": "ويب كومكس باللغة {al_ar}",
    "{en} language webcomics": "ويب كومكس باللغة {al_ar}",
    "{en} language websites": "مواقع ويب باللغة {al_ar}",
    "{en} language words and phrases": "كلمات وجمل باللغة {al_ar}",
    "{en} language works": "أعمال باللغة {al_ar}",
}


def add_definite_article(label: str) -> str:
    """Prefix each word in ``label`` with the Arabic definite article."""
    label = re.sub(r" ال", " ", f" {label} ").strip()
    label_without_article = re.sub(r" ", " ال", label)
    new_label = f"ال{label_without_article}"
    return new_label


@functools.lru_cache(maxsize=1)
def _make_bot() -> MultiDataFormatterBase:
    formatted_data = {
        "{lang_en} language {film_en} films": "أفلام {film_ar} باللغة {lang_al}",
    }
    put_label_last = {
        "low-budget",
        "supernatural",
        "christmas",
        "lgbtq-related",
        "upcoming",
    }

    data = {x: add_definite_article(v) for x, v in new_data.items()}
    bot = format_films_country_data(
        formatted_data=formatted_data,
        data_list=data,
        key_placeholder="{lang_en}",
        value_placeholder="{lang_al}",
        data_list2=film_keys_for_female,
        key2_placeholder="{film_en}",
        value2_placeholder="{film_ar}",
        text_after="",
        text_before="",
        data_to_find=Films_key_CAO,
        # other_formatted_data=other_formatted_data,
    )

    # bot.other_bot.update_put_label_last(put_label_last)

    return bot


@functools.lru_cache(maxsize=1)
def _load_bot() -> FormatDataV2:
    data = {
        x: {
            "ar": v,
            "al_ar": add_definite_article(v),
        }
        for x, v in new_data.items()
    }

    return FormatDataV2(
        formatted_data=formatted_data,
        data_list=data,
        key_placeholder="{en}",
        # text_after=" language",
        text_before="",
    )


def fix_keys(category: str) -> str:
    category = category.replace("'", "").lower()
    category = category.replace("-language ", " language ")
    return category


@functools.lru_cache(maxsize=10000)
def resolve_languages_labels(category: str) -> str:
    logger.debug(f"<<yellow>> start resolve_languages_labels: {category=}")

    category = fix_keys(category)

    result = _load_bot().search_all_category(category) or _make_bot().search_all_category(category) or ""

    logger.info_if_or_debug(f"<<yellow>> end resolve_languages_labels: {category=}, {result=}", result)
    return result


__all__ = [
    "resolve_languages_labels",
]



"""
tests
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new_resolvers.relations_resolver.nationalities_double_v2 import resolve_by_nats_double_v2

nats_1 = {
    "yemeni–lebanese conflict": "الصراع اللبناني اليمني",
    "zimbabwean–palestinian conflict legal issues": "قضايا قانونية في الصراع الزيمبابوي الفلسطيني",
    "zimbabwean–palestinian conflict video games": "ألعاب فيديو الصراع الزيمبابوي الفلسطيني",
    "zimbabwean–palestinian conflict": "الصراع الزيمبابوي الفلسطيني",
    "zimbabwean–palestinian joint economic efforts": "الجهود الاقتصادية المشتركة الزيمبابوية الفلسطينية",
}

nats_2 = {}


@pytest.mark.parametrize("category, expected", nats_1.items(), ids=nats_1.keys())
@pytest.mark.fast
def test_nats_1(category: str, expected: str) -> None:
    label = resolve_by_nats_double_v2(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", nats_2.items(), ids=nats_2.keys())
@pytest.mark.fast
def test_nats_2(category: str, expected: str) -> None:
    label = resolve_by_nats_double_v2(category)
    assert label == expected


TEMPORAL_CASES = [("nats_1", nats_1, resolve_by_nats_double_v2), ("nats_2", nats_2, resolve_by_nats_double_v2)]


@pytest.mark.parametrize("name,data,callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_dump_all(name: str, data: str, callback: str) -> None:
    name = f"{__name__}_{name}"
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, f"test_resolve_resolve_by_nats_double_v2_{name}")

    # dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Unit tests"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

fencers_rugby = {
    "Category:Paralympic medalists in wheelchair basketball": "تصنيف:فائزون بميداليات الألعاب البارالمبية في كرة السلة على الكراسي المتحركة",
    "Category:Paralympic medalists in wheelchair curling": "تصنيف:فائزون بميداليات الألعاب البارالمبية في الكيرلنغ على الكراسي المتحركة",
    "Category:Paralympic medalists in wheelchair fencing": "تصنيف:فائزون بميداليات الألعاب البارالمبية في مبارزة سيف الشيش على الكراسي المتحركة",
    "Category:Paralympic medalists in wheelchair rugby": "تصنيف:فائزون بميداليات الألعاب البارالمبية في الرجبي على الكراسي المتحركة",
    "Category:Paralympic medalists in wheelchair tennis": "تصنيف:فائزون بميداليات الألعاب البارالمبية في كرة المضرب على الكراسي المتحركة",
    "Category:Paralympic wheelchair basketball coaches": "تصنيف:مدربو كرة سلة على كراسي متحركة في الألعاب البارالمبية",
    "Category:Paralympic wheelchair basketball players by country": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية حسب البلد",
    "Category:Paralympic wheelchair basketball players by year": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية حسب السنة",
    "Category:Paralympic wheelchair basketball players for Australia": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في أستراليا",
    "Category:Paralympic wheelchair basketball players for Canada": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في كندا",
    "Category:Paralympic wheelchair basketball players for France": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في فرنسا",
    "Category:Paralympic wheelchair basketball players for Germany": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في ألمانيا",
    "Category:Paralympic wheelchair basketball players for Great Britain": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في بريطانيا العظمى",
    "Category:Paralympic wheelchair basketball players for Israel": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في إسرائيل",
    "Category:Paralympic wheelchair basketball players for Japan": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في اليابان",
    "Category:Paralympic wheelchair basketball players for South Africa": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في جنوب إفريقيا",
    "Category:Paralympic wheelchair basketball players for Spain": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في إسبانيا",
    "Category:Paralympic wheelchair basketball players for the Netherlands": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في هولندا",
    "Category:Paralympic wheelchair basketball players for the United States": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في الولايات المتحدة",
    "Category:Paralympic wheelchair basketball players for Turkey": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في تركيا",
    "Category:Paralympic wheelchair basketball players": "تصنيف:لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية",
    "Category:Paralympic wheelchair curlers by country": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية حسب البلد",
    "Category:Paralympic wheelchair curlers by year": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية حسب السنة",
    "Category:Paralympic wheelchair curlers for Canada": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في كندا",
    "Category:Paralympic wheelchair curlers for China": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في الصين",
    "Category:Paralympic wheelchair curlers for Denmark": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في الدنمارك",
    "Category:Paralympic wheelchair curlers for Finland": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في فنلندا",
    "Category:Paralympic wheelchair curlers for Germany": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في ألمانيا",
    "Category:Paralympic wheelchair curlers for Great Britain": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في بريطانيا العظمى",
    "Category:Paralympic wheelchair curlers for Italy": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في إيطاليا",
    "Category:Paralympic wheelchair curlers for Japan": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في اليابان",
    "Category:Paralympic wheelchair curlers for Latvia": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في لاتفيا",
    "Category:Paralympic wheelchair curlers for Norway": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في النرويج",
    "Category:Paralympic wheelchair curlers for Russia": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في روسيا",
    "Category:Paralympic wheelchair curlers for Slovakia": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في سلوفاكيا",
    "Category:Paralympic wheelchair curlers for South Korea": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في كوريا الجنوبية",
    "Category:Paralympic wheelchair curlers for Sweden": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في السويد",
    "Category:Paralympic wheelchair curlers for Switzerland": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في سويسرا",
    "Category:Paralympic wheelchair curlers for the United States": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية في الولايات المتحدة",
    "Category:Paralympic wheelchair curlers": "تصنيف:لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية",
    "Category:Paralympic wheelchair fencers by country": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية حسب البلد",
    "Category:Paralympic wheelchair fencers by year": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية حسب السنة",
    "Category:Paralympic wheelchair fencers for Australia": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في أستراليا",
    "Category:Paralympic wheelchair fencers for Belarus": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في روسيا البيضاء",
    "Category:Paralympic wheelchair fencers for Brazil": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في البرازيل",
    "Category:Paralympic wheelchair fencers for Canada": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في كندا",
    "Category:Paralympic wheelchair fencers for China": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في الصين",
    "Category:Paralympic wheelchair fencers for France": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في فرنسا",
    "Category:Paralympic wheelchair fencers for Georgia (country)": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في جورجيا",
    "Category:Paralympic wheelchair fencers for Germany": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في ألمانيا",
    "Category:Paralympic wheelchair fencers for Great Britain": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في بريطانيا العظمى",
    "Category:Paralympic wheelchair fencers for Hong Kong": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في هونغ كونغ",
    "Category:Paralympic wheelchair fencers for Hungary": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في المجر",
    "Category:Paralympic wheelchair fencers for Iraq": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في العراق",
    "Category:Paralympic wheelchair fencers for Israel": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في إسرائيل",
    "Category:Paralympic wheelchair fencers for Italy": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في إيطاليا",
    "Category:Paralympic wheelchair fencers for Japan": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في اليابان",
    "Category:Paralympic wheelchair fencers for Latvia": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في لاتفيا",
    "Category:Paralympic wheelchair fencers for Poland": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في بولندا",
    "Category:Paralympic wheelchair fencers for Russia": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في روسيا",
    "Category:Paralympic wheelchair fencers for Spain": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في إسبانيا",
    "Category:Paralympic wheelchair fencers for Thailand": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في تايلاند",
    "Category:Paralympic wheelchair fencers for the United States": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في الولايات المتحدة",
    "Category:Paralympic wheelchair fencers for Turkey": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في تركيا",
    "Category:Paralympic wheelchair fencers for Ukraine": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية في أوكرانيا",
    "Category:Paralympic wheelchair fencers": "تصنيف:مبارزون على الكراسي المتحركة في الألعاب البارالمبية",
    "Category:Paralympic wheelchair rugby coaches": "تصنيف:مدربو رجبي على كراسي متحركة في الألعاب البارالمبية",
    "Category:Paralympic wheelchair rugby players by country": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية حسب البلد",
    "Category:Paralympic wheelchair rugby players by year": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية حسب السنة",
    "Category:Paralympic wheelchair rugby players for Australia": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية في أستراليا",
    "Category:Paralympic wheelchair rugby players for Canada": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية في كندا",
    "Category:Paralympic wheelchair rugby players for Great Britain": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية في بريطانيا العظمى",
    "Category:Paralympic wheelchair rugby players for Japan": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية في اليابان",
    "Category:Paralympic wheelchair rugby players for New Zealand": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية في نيوزيلندا",
    "Category:Paralympic wheelchair rugby players for the United States": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية في الولايات المتحدة",
    "Category:Paralympic wheelchair rugby players": "تصنيف:لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية",
}


wheelchair_tennis = {
    "Category:Paralympic wheelchair tennis players by country": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية حسب البلد",
    "Category:Paralympic wheelchair tennis players by year": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية حسب السنة",
    "Category:Paralympic wheelchair tennis players for Argentina": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في الأرجنتين",
    "Category:Paralympic wheelchair tennis players for Australia": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في أستراليا",
    "Category:Paralympic wheelchair tennis players for Austria": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في النمسا",
    "Category:Paralympic wheelchair tennis players for Belgium": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في بلجيكا",
    "Category:Paralympic wheelchair tennis players for Brazil": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في البرازيل",
    "Category:Paralympic wheelchair tennis players for Canada": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في كندا",
    "Category:Paralympic wheelchair tennis players for Chile": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في تشيلي",
    "Category:Paralympic wheelchair tennis players for China": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في الصين",
    "Category:Paralympic wheelchair tennis players for Colombia": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في كولومبيا",
    "Category:Paralympic wheelchair tennis players for France": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في فرنسا",
    "Category:Paralympic wheelchair tennis players for Germany": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في ألمانيا",
    "Category:Paralympic wheelchair tennis players for Great Britain": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في بريطانيا العظمى",
    "Category:Paralympic wheelchair tennis players for Hungary": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في المجر",
    "Category:Paralympic wheelchair tennis players for Israel": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في إسرائيل",
    "Category:Paralympic wheelchair tennis players for Japan": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في اليابان",
    "Category:Paralympic wheelchair tennis players for Poland": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في بولندا",
    "Category:Paralympic wheelchair tennis players for South Africa": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في جنوب إفريقيا",
    "Category:Paralympic wheelchair tennis players for Spain": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في إسبانيا",
    "Category:Paralympic wheelchair tennis players for Sri Lanka": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في سريلانكا",
    "Category:Paralympic wheelchair tennis players for Sweden": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في السويد",
    "Category:Paralympic wheelchair tennis players for Switzerland": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في سويسرا",
    "Category:Paralympic wheelchair tennis players for Thailand": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في تايلاند",
    "Category:Paralympic wheelchair tennis players for the Netherlands": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في هولندا",
    "Category:Paralympic wheelchair tennis players for the United States": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في الولايات المتحدة",
    "Category:Paralympic wheelchair tennis players for Turkey": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية في تركيا",
    "Category:Paralympic wheelchair tennis players": "تصنيف:لاعبو كرة مضرب على كراسي متحركة في الألعاب البارالمبية",
}


test_data = [
    ("test_wheelchair_fencers_rugby", fencers_rugby),
    ("test_wheelchair_tennis", wheelchair_tennis),
]


@pytest.mark.parametrize("category, expected", fencers_rugby.items(), ids=fencers_rugby.keys())
@pytest.mark.fast
def test_wheelchair_fencers_rugby(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", wheelchair_tennis.items(), ids=wheelchair_tennis.keys())
@pytest.mark.fast
def test_wheelchair_tennis(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.dump
@pytest.mark.parametrize("name,data", test_data)
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""
"""

import functools

from ...helps import len_print, logger

# from ...helps.jsonl_dump import dump_data
from ...new.handle_suffixes import resolve_sport_category_suffix_with_mapping
from ...translations.sports.Sport_key import (
    SPORTS_KEYS_FOR_JOBS,
    SPORTS_KEYS_FOR_LABEL,
    SPORTS_KEYS_FOR_TEAM,
)
from ...translations_formats import FormatData
from .sport_lab2_data import jobs_formatted_data, labels_formatted_data, teams_formatted_data

labels_bot = FormatData(
    labels_formatted_data,
    SPORTS_KEYS_FOR_LABEL,
    key_placeholder="{en_sport}",
    value_placeholder="{sport_label}",
)
teams_bot = FormatData(
    teams_formatted_data,
    SPORTS_KEYS_FOR_TEAM,
    key_placeholder="{en_sport}",
    value_placeholder="{sport_team}",
)
jobs_bot = FormatData(
    jobs_formatted_data,
    SPORTS_KEYS_FOR_JOBS,
    key_placeholder="{en_sport}",
    value_placeholder="{sport_jobs}",
)


@functools.lru_cache(maxsize=1)
def _get_sorted_teams_labels() -> dict[str, str]:
    mappings_data = {
        "records and statistics": "سجلات وإحصائيات",
        "finals": "نهائيات",
        "matches": "مباريات",
        "manager history": "تاريخ مدربو",
        "tournaments": "بطولات",
        "leagues": "دوريات",
        "coaches": "مدربو",
        "clubs and teams": "أندية وفرق",
        "clubs": "أندية",
        "competitions": "منافسات",
        "chairmen and investors": "رؤساء ومسيرو",
        "cups": "كؤوس",
    }

    mappings_data = dict(
        sorted(
            mappings_data.items(),
            key=lambda k: (-k[0].count(" "), -len(k[0])),
        )
    )
    return mappings_data


def fix_result_callable(result: str, category: str, key: str, value: str) -> str:
    if result.startswith("لاعبو ") and "للسيدات" in result:
        result = result.replace("لاعبو ", "لاعبات ")

    if key == "teams" and "national" in category:
        result = result.replace("فرق ", "منتخبات ")

    return result


@functools.lru_cache(maxsize=None)
def find_labels_bot(category: str, default: str = "") -> str:
    """Search for a generic sports label, returning ``default`` when missing."""
    return labels_bot.search(category) or default


@functools.lru_cache(maxsize=None)
def find_teams_bot(category: str, default: str = "") -> str:
    """Search for a team-related label, returning ``default`` when missing."""
    category = category.replace("championships", "championship")
    return teams_bot.search(category) or default


@functools.lru_cache(maxsize=None)
def find_jobs_bot(category: str, default: str = "") -> str:
    """Search for a job-related sports label, returning ``default`` when missing."""
    return jobs_bot.search(category) or default


@functools.lru_cache(maxsize=None)
def wrap_team_xo_normal_2025(team: str) -> str:
    """Normalize a team string and resolve it via the available sports bots."""
    team = team.lower().replace("category:", "")
    result = find_labels_bot(team) or find_teams_bot(team) or find_jobs_bot(team) or ""
    return result.strip()


@functools.lru_cache(maxsize=10000)
def fix_keys(category: str) -> str:
    category = category.replace("'", "").lower().replace("category:", "")

    return category.strip()


def wrap_team_xo_normal_2025_with_ends(category, callback=wrap_team_xo_normal_2025) -> str:
    category = fix_keys(category)
    logger.debug(f"<<yellow>> start wrap_team_xo_normal_2025_with_ends: {category=}")
    teams_label_mappings_ends = _get_sorted_teams_labels()

    result = callback(category)

    if not result:
        result = resolve_sport_category_suffix_with_mapping(
            category=category,
            data=teams_label_mappings_ends,
            callback=callback,
            fix_result_callable=fix_result_callable,
        )

    logger.info_if_or_debug(f"<<yellow>> end wrap_team_xo_normal_2025_with_ends: {category=}, {result=}", result)
    return result


__all__ = [
    "wrap_team_xo_normal_2025",
    "find_labels_bot",
    "find_teams_bot",
    "find_jobs_bot",
    "wrap_team_xo_normal_2025_with_ends",
]



"""
Tests for matables_bots.bot module functions.
"""

import pytest

from ArWikiCats import resolve_arabic_category_label
from ArWikiCats.legacy_bots.matables_bots.bot import Films_O_TT, add_to_Films_O_TT, add_to_new_players, players_new_keys


@pytest.mark.fast
def test_add_to_new_players() -> None:
    """Test add_to_new_players function with various inputs."""
    # Test with valid inputs
    test_key = "test_player_key"
    test_value = "قيمة الاختبار"

    # Add a test entry
    add_to_new_players(test_key, test_value)

    # Verify it was added
    assert test_key in players_new_keys
    assert players_new_keys[test_key] == test_value

    # Test with empty strings (should not add anything)
    initial_count = len(players_new_keys)
    add_to_new_players("", "arabic")
    assert len(players_new_keys) == initial_count

    add_to_new_players("english", "")
    assert len(players_new_keys) == initial_count

    # Test with both empty (should not add anything)
    add_to_new_players("", "")
    assert len(players_new_keys) == initial_count


@pytest.mark.fast
def test_add_to_new_players_invalid_types() -> None:
    """Test add_to_new_players with invalid types."""
    initial_count = len(players_new_keys)

    # Test with None values (should not add)
    add_to_new_players(None, "arabic")
    assert len(players_new_keys) == initial_count

    add_to_new_players("english", None)
    assert len(players_new_keys) == initial_count

    # Test with non-string types
    add_to_new_players(123, "arabic")
    assert len(players_new_keys) == initial_count

    add_to_new_players("english", 456)
    assert len(players_new_keys) == initial_count


@pytest.mark.fast
def test_add_to_Films_O_TT() -> None:
    """Test add_to_Films_O_TT function with various inputs."""
    # Test with valid inputs
    test_key = "test_film_key"
    test_value = "قيمة فيلم الاختبار"

    # Add a test entry
    add_to_Films_O_TT(test_key, test_value)

    # Verify it was added
    assert test_key in Films_O_TT
    assert Films_O_TT[test_key] == test_value

    # Test with empty strings (should not add anything)
    initial_count = len(Films_O_TT)
    add_to_Films_O_TT("", "arabic")
    assert len(Films_O_TT) == initial_count

    add_to_Films_O_TT("english", "")
    assert len(Films_O_TT) == initial_count

    # Test with both empty (should not add anything)
    add_to_Films_O_TT("", "")
    assert len(Films_O_TT) == initial_count


@pytest.mark.fast
def test_add_to_Films_O_TT_invalid_types() -> None:
    """Test add_to_Films_O_TT with invalid types."""
    initial_count = len(Films_O_TT)

    # Test with None values (should not add)
    add_to_Films_O_TT(None, "arabic")
    assert len(Films_O_TT) == initial_count

    add_to_Films_O_TT("english", None)
    assert len(Films_O_TT) == initial_count

    # Test with non-string types
    add_to_Films_O_TT(123, "arabic")
    assert len(Films_O_TT) == initial_count

    add_to_Films_O_TT("english", 456)
    assert len(Films_O_TT) == initial_count


@pytest.mark.fast
def test_add_to_new_players_overwrite() -> None:
    """Test that add_to_new_players can overwrite existing keys."""
    test_key = "overwrite_test_key"
    first_value = "قيمة أولى"
    second_value = "قيمة ثانية"

    # Add initial value
    add_to_new_players(test_key, first_value)
    assert players_new_keys[test_key] == first_value

    # Overwrite with new value
    add_to_new_players(test_key, second_value)
    assert players_new_keys[test_key] == second_value


@pytest.mark.fast
def test_add_to_Films_O_TT_overwrite() -> None:
    """Test that add_to_Films_O_TT can overwrite existing keys."""
    test_key = "overwrite_film_key"
    first_value = "قيمة فيلم أولى"
    second_value = "قيمة فيلم ثانية"

    # Add initial value
    add_to_Films_O_TT(test_key, first_value)
    assert Films_O_TT[test_key] == first_value

    # Overwrite with new value
    add_to_Films_O_TT(test_key, second_value)
    assert Films_O_TT[test_key] == second_value


@pytest.mark.fast
def test_players_new_keys_is_dict() -> None:
    """Test that players_new_keys is a dictionary."""
    assert isinstance(players_new_keys, dict)
    assert len(players_new_keys) > 0  # Should have some predefined entries


@pytest.mark.fast
def test_Films_O_TT_is_dict() -> None:
    """Test that Films_O_TT is a dictionary."""
    assert isinstance(Films_O_TT, dict)



#!/usr/bin/python3
"""
Build lookup tables for translating sport related keys.
"""

from dataclasses import dataclass
from typing import Final, Mapping, MutableMapping, TypedDict

from ...helps import len_print, logger
from ..utils.json_dir import open_json_file


class SportKeyRecord(TypedDict, total=False):
    """Typed representation of a single sport key translation."""

    label: str
    team: str
    jobs: str
    olympic: str


ALIASES: Final[Mapping[str, str]] = {
    "kick boxing": "kickboxing",
    "sport climbing": "climbing",
    "aquatic sports": "aquatics",
    "shooting": "shooting sport",
    "motorsports": "motorsport",
    "road race": "road cycling",
    "cycling road race": "road cycling",
    "road bicycle racing": "road cycling",
    "auto racing": "automobile racing",
    "bmx racing": "bmx",
    "equestrianism": "equestrian",
    "mountain bike racing": "mountain bike",
}


@dataclass(frozen=True)
class SportKeyTables:
    """Container with convenience accessors for specific dictionaries."""

    label: dict[str, str]
    jobs: dict[str, str]
    team: dict[str, str]
    olympic: dict[str, str]


def _coerce_record(raw: Mapping[str, object]) -> SportKeyRecord:
    """Convert a raw JSON entry into a :class:`SportKeyRecord`."""

    return SportKeyRecord(
        label=str(raw.get("label", "")),
        jobs=str(raw.get("jobs", "")),
        team=str(raw.get("team", "")),
        olympic=str(raw.get("olympic", "")),
    )


def _load_base_records() -> dict[str, SportKeyRecord]:
    """Load sports key definitions from the JSON configuration file."""

    data = open_json_file("sports/Sports_Keys_New.json") or {}
    records: dict[str, SportKeyRecord] = {}

    if not isinstance(data, Mapping):
        logger.warning("Unexpected sports key payload type: %s", type(data))
        return records

    multi_sport_key = {
        "multi-sport": {
            "label": "رياضية متعددة",
            "team": "",
            "jobs": "رياضية متعددة",
            "olympic": "رياضية متعددة أولمبية",
        },
        "sports": {
            "label": "ألعاب رياضية",
            "team": "للرياضة",
            "jobs_old": "رياضية",
            "jobs": "",
            "olympic": "رياضية أولمبية",
        },
    }
    # data.update(multi_sport_key)
    sports_key = {
        "sports": {"label": "رياضات", "team": "للرياضات", "jobs_old": "", "jobs": "رياضية", "olympic": "رياضات أولمبية"}
    }
    # data.update(sports_key)

    for key, value in data.items():
        if isinstance(key, str) and isinstance(value, Mapping):
            if value.get("ignore"):
                continue
            records[key] = _coerce_record(value)
        else:  # pragma: no cover - defensive branch
            logger.debug("Skipping malformed sports key entry: %s", key)

    return records


def _copy_record(record: SportKeyRecord, **overrides: str) -> SportKeyRecord:
    """Return a shallow copy of ``record`` applying ``overrides``."""

    updated: SportKeyRecord = SportKeyRecord(
        label=record.get("label", ""),
        jobs=record.get("jobs", ""),
        team=record.get("team", ""),
        olympic=record.get("olympic", ""),
    )

    for field, value in overrides.items():
        if value:
            updated[field] = value

    return updated


def _apply_aliases(records: MutableMapping[str, SportKeyRecord]) -> None:
    """Populate alias keys by copying the values from the canonical entry."""

    for alias, source in ALIASES.items():
        record = records.get(source)
        if record is None:
            logger.debug("Missing source record for alias: %s -> %s", alias, source)
            continue
        records[alias] = _copy_record(record)


def _generate_variants(records: Mapping[str, SportKeyRecord]) -> dict[str, SportKeyRecord]:
    """Create derived entries such as ``"{sport} racing"`` and wheelchair keys."""

    keys_to_wheelchair = [
        "sports",
        "basketball",
        "rugby league",
        "rugby",
        "tennis",
        "handball",
        "beach handball",
        "curling",
        "fencing",
    ]

    variants: dict[str, SportKeyRecord] = {}
    for sport, record in records.items():
        label = record.get("label", "")
        jobs = record.get("jobs", "")
        olympic = record.get("olympic", "")
        team = record.get("team", "")

        if not sport.endswith("racing") and not label.startswith("سباق") and not jobs.startswith("سباق"):
            variants[f"{sport} racing"] = _copy_record(
                record,
                label=f"سباق {label}",
                team=f"لسباق {label}",
                jobs=f"سباق {jobs}",
                olympic=f"سباق {olympic}",
            )

        if sport in keys_to_wheelchair:
            variants[f"wheelchair {sport}"] = _copy_record(
                record,
                label=f"{label} على الكراسي المتحركة",
                team=f"{team} على الكراسي المتحركة",
                jobs=f"{jobs} على كراسي متحركة",
                olympic=f"{olympic} على كراسي متحركة",
            )

    return variants


def _build_tables(records: Mapping[str, SportKeyRecord]) -> SportKeyTables:
    """Create lookups for each translation category."""

    tables: dict[str, dict[str, str]] = {
        "label": {},
        "team": {},
        "jobs": {},
        "olympic": {},
    }

    for sport, record in records.items():
        for field in tables.keys():
            value = record.get(field, "")
            if value:
                tables[field][sport.lower()] = value

    return SportKeyTables(
        label=tables["label"],
        jobs=tables["jobs"],
        team=tables["team"],
        olympic=tables["olympic"],
    )


def _initialise_tables() -> dict[str, SportKeyRecord]:
    """Load data, expand aliases and variants, and build helper tables."""

    records = _load_base_records()
    _apply_aliases(records)

    return records


SPORT_KEY_RECORDS_BASE: dict[str, SportKeyRecord] = _initialise_tables()
# Variants are created in a separate dictionary to avoid modifying the
# collection while iterating over it.
SPORT_KEY_RECORDS_VARIANTS = _generate_variants(SPORT_KEY_RECORDS_BASE)

SPORT_KEY_RECORDS = SPORT_KEY_RECORDS_BASE | SPORT_KEY_RECORDS_VARIANTS

SPORT_KEY_TABLES: SportKeyTables = _build_tables(SPORT_KEY_RECORDS)

SPORTS_KEYS_FOR_TEAM: Final[dict[str, str]] = SPORT_KEY_TABLES.team
SPORTS_KEYS_FOR_OLYMPIC: Final[dict[str, str]] = SPORT_KEY_TABLES.olympic

SPORTS_KEYS_FOR_LABEL: Final[dict[str, str]] = SPORT_KEY_TABLES.label
# SPORTS_KEYS_FOR_LABEL["sports"] = "رياضات"
# SPORTS_KEYS_FOR_LABEL["sports"] = "ألعاب رياضية"

SPORTS_KEYS_FOR_JOBS: Final[dict[str, str]] = SPORT_KEY_TABLES.jobs
SPORTS_KEYS_FOR_JOBS["sports"] = "رياضية"

len_print.data_len(
    "Sport_key.py",
    {
        "SPORT_KEY_RECORDS": SPORT_KEY_RECORDS,
        "SPORT_KEY_RECORDS_BASE": SPORT_KEY_RECORDS_BASE,
        "SPORT_KEY_RECORDS_VARIANTS": SPORT_KEY_RECORDS_VARIANTS,
        "SPORTS_KEYS_FOR_LABEL": SPORTS_KEYS_FOR_LABEL,
        "SPORTS_KEYS_FOR_JOBS": SPORTS_KEYS_FOR_JOBS,
        "SPORTS_KEYS_FOR_OLYMPIC": SPORTS_KEYS_FOR_OLYMPIC,
        "SPORTS_KEYS_FOR_TEAM": SPORTS_KEYS_FOR_TEAM,
    },
)

__all__ = [
    "SPORT_KEY_RECORDS",
    "SPORT_KEY_RECORDS_BASE",
    "SPORT_KEY_RECORDS_VARIANTS",
    "SPORT_KEY_TABLES",
    "SPORTS_KEYS_FOR_LABEL",
    "SPORTS_KEYS_FOR_JOBS",
    "SPORTS_KEYS_FOR_OLYMPIC",
    "SPORTS_KEYS_FOR_TEAM",
]
